@@ -53,6 +53,14 @@
         <source>Reboot</source>
         <translation>Neustarten</translation>
     </message>
+    <message>
+        <source>Suspend</source>
+        <translation>Ruhezustand</translation>
+    </message>
+    <message>
+        <source>Hibernate</source>
+        <translation>Tiefschlaf</translation>
+    </message>
     <message>
         <source>Session</source>
         <translation>Sitzung</translation>
@@ -65,6 +73,14 @@
         <source>User name</source>
         <translation>Benutzername</translation>
     </message>
+    <message>
+        <source>Enter your username</source>
+        <translation>Bitte Benutzername eingeben</translation>
+    </message>
+    <message>
+        <source>Enter your password</source>
+        <translation>Bitte Passwort eingeben</translation>
+    </message>
     <message>
         <source>Select your user and enter password</source>
         <translation>Benutzer auswählen und Passwort eingeben</translation>
