@@ -93,8 +93,7 @@ namespace SDDM {
         }
     }
 
-    SeatManager::SeatManager(QObject *parent) : QObject(parent) {
-
+    void SeatManager::initialize() {
         if (DaemonApp::instance()->testing() || !Logind::isAvailable()) {
             //if we don't have logind/CK2, just create a single seat immediately and don't do any other connections
             createSeat(QStringLiteral("seat0"));
